@@ -3,6 +3,8 @@ package TestApp;
 use strict;
 use warnings;
 
+use MRO::Compat;
+
 use Catalyst qw/ConfigLoader/;
 
 our $VERSION = '0.01';
@@ -12,12 +14,7 @@ __PACKAGE__->setup;
 sub finalize_config {
     my $c = shift;
     $c->config( foo => 'bar' );
-    $c->NEXT::finalize_config;
-}
-
-sub appconfig : Local {
-    my ( $self, $c, $var ) = @_;
-    $c->res->body( $c->config->{ $var } );
+    $c->next::method( @_ );
 }
 
 1;
